@@ -3,7 +3,7 @@ BEGIN {
   $Linux::Smaps::Tiny::AUTHORITY = 'cpan:AVAR';
 }
 BEGIN {
-  $Linux::Smaps::Tiny::VERSION = '0.07';
+  $Linux::Smaps::Tiny::VERSION = '0.08';
 }
 use strict;
 use warnings FATAL => "all";
@@ -35,7 +35,7 @@ Linux::Smaps::Tiny - A minimal and fast alternative to L<Linux::Smaps>
     my $shared_clean = $summary->{Shared_Clean};
     my $shared_dirty = $summary->{Shared_Dirty};
 
-    warn "Size / Clean / Dirty = $size / $shared_clean/ $shared_dirty";
+    print "Size / Clean / Dirty = $size / $shared_clean / $shared_dirty\n";
 
 =head1 DESCRIPTION
 
